==> cool_utils-1.2.0.1-py3-none-any.whl: cool_utils/cache.py <==
"""
BSD 3-Clause License

Copyright (c) 2021-present, BenitzCoding
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this
   list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.

3. Neither the name of the copyright holder nor the names of its
   contributors may be used to endorse or promote products derived from
   this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
"""

from typing import TypeVar

cache = {
	"size": 0
}

__all__ = (
	'Cache'
)

T = TypeVar('T', bound='Cache')

class Cache:
	def store( variable: str, value ):
		payload = {
			"size": (1 + cache["size"]),
			f"{variable}": value
		}
		cache.update(payload)
		return

	def load( variable: str ):
		try:
			return cache[variable]
		except:
			return None

	def size():
		return cache["size"]

	def clear():
		key_list = []
		for key, value in cache.items():
			if key == "size":
				continue
			key_list.append(key)
		
		for key in key_list:
			del cache[key]

		default_payload = {
			"size": 0
		}

		cache.update(default_payload)
		return

	def remove( variable: str ):
		try:
			del cache[variable]
			return True
		except:
			return False

==> cool_utils-1.2.1.4-py3-none-any.whl: cool_utils/cache.py <==
"""
BSD 3-Clause License

Copyright (c) 2021-present, BenitzCoding
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this
   list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.

3. Neither the name of the copyright holder nor the names of its
   contributors may be used to endorse or promote products derived from
   this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
"""

from typing import TypeVar, Any

cache = {
	"size": 0
}

__all__ = (
	'Cache'
)

T = TypeVar('T', bound='Cache')

class Cache:
	def store(variable: str, value) -> None:
		payload = {
			"size": (1 + cache["size"]),
			f"{variable}": value
		}
		cache.update(payload)
		return None

	def load(variable) -> Any:
		try:
			return cache[variable]
		except:
			return None

	def size() -> int:
		return cache["size"]

	def clear() -> None:
		key_list = []
		for key, value in cache.items():
			if key == "size":
				continue
			key_list.append(key)
		
		for key in key_list:
			del cache[key]

		default_payload = {
			"size": 0
		}

		cache.update(default_payload)
		return None

	def remove(variable) -> bool:
		try:
			del cache[variable]
			return True
		except:
			return False
